@@ -1,5 +1,14 @@
 """
-Generates examples of dfs to play around with
+For Tabular_ML Predictions.
+
+This serves to simulate the data and API of the tabular_prediction_analyzer.
+
+For now, it is the main module for the tabular ML analyzer and just
+serves as an example of what is possible.
+
+Should inherit a Base Class Analyzer in the future that users can
+use with real numpy or pandas data.
+
 """
 
 import sklearn.datasets
@@ -14,6 +23,13 @@ import pandas as pd
 from src.analyze import Analyzer
 
 def get_classification(random_state = 42):
+    """
+    Creates a classification dataset.
+    Wrapper for sklearn's make_classification.
+
+    :param random_state: Specifies a random seed
+    :return: A tuple of X,y values.
+    """
     X, y = sklearn.datasets.make_classification(
         n_samples = 1000,
         n_classes = 5,
@@ -307,6 +323,41 @@ class ExampleClassificationAnalyzer():
         in the X field on these samples to find out
         if they have something in common.
 
+        :return:
+        """
+
+        trues_df = self.preds_df.copy()
+
+        # Set all to the trues for easy comparison.
+        for col in trues_df.columns:
+            trues_df[col] = self.y_true
+
+
+        correct_mask = trues_df == self.preds_df
+
+        self.correct_mask = correct_mask
+
+        n_correct = correct_mask.sum(axis = 1).sort_values()
+
+        self.n_correct = n_correct
+
+        print(n_correct)
+        print(n_correct.value_counts().sort_values())
+
+        return n_correct
+
+
+    def find_most_variance(self):
+        """
+        This function finds the samples that had
+        the most variance across them.
+
+        Highest std / variance.
+
+        What does this mean in terms of Classification?
+        Most different guesses.
+
+
         :return:
         """
         pass
@@ -353,6 +404,15 @@ class ExampleClassificationAnalyzer():
         self.add_metric_to_metric_df(self.preds_df.median,
                                      "median_ensemble")
 
+    def fit_mode_ensemble(self):
+
+        # This doesn't work.
+        # Gives ValueError: Cannot convert non-finite values (NA or inf) to integer
+
+        #self.add_metric_to_metric_df(self.preds_df.mode,
+        #                             "mode_ensemble")
+        pass
+
     def fit_all_stats_ensembles(self):
 
         self.fit_mean_ensemble()
@@ -394,8 +454,3 @@ class ExampleClassificationAnalyzer():
     def bootstrap(self):
         pass
 
-
-### For testing
-
-#%%
-ex = ExampleClassificationAnalyzer()
\ No newline at end of file
